import request from '@/utils/request';

function getCurrentTimestamp() {
  return new Date().getTime();
}
const api = 'http://nbxt.oa.x-lf.cn'

//我负责的页面获取项目
export function GetProject(page, pageSize, token) {
  return request({
    url:api + '/project/my/get',
    method: 'get',
    params: { page, pageSize },
    headers: {
      'Authorization':'Bearer '+ token,
      'content-type': 'application/json;charset=utf-8',
      'Timestamp': getCurrentTimestamp()
    }
  });
}

//新增项目
export function AddProject(data, token) {
  return request({
    url:api + '/project/add',
    method: 'post',
    data,
    headers: {
      'Authorization':'Bearer '+ token,
      'content-type': 'application/json;charset=utf-8',
      'Timestamp': getCurrentTimestamp()
    }
  });
}

//删除项目
export function DeleteProject(id, token) {
  return request({
    url:api + '/project/delete',
    method: 'delete',
    params:{ id },
    headers: {
      'Authorization':'Bearer '+ token,
      'content-type': 'application/json;charset=utf-8',
      'Timestamp': getCurrentTimestamp()
    }
  });
}

//编辑项目
export function EditProject(id, data, token) {
  return request({
    url:api + '/project/edit',
    method: 'put',
    params:{ id },
    data,
    headers: {
      'Authorization': 'Bearer ' + token,
      'content-type': 'application/json;charset=utf-8',
      'Timestamp': getCurrentTimestamp()
    }
  });
}

//根据项目名字模糊查询
export function GetProjectByName(name, token) {
  return request({
    url:api + '/project/get/name',
    method: 'get',
    params: { name },
    headers: {
      'Authorization':'Bearer '+ token,
      'content-type': 'application/json;charset=utf-8',
      'Timestamp': getCurrentTimestamp()
    }
  });
}

//根据项目id查询子系统
export function GetChildSysById(projectId, token) {
  return request({
    url:api +  "/module/get?projectId=" + projectId ,
    method: 'get',
    params: { projectId },
    headers: {
      'Authorization':'Bearer '+ token,
      'content-type': 'application/json;charset=utf-8',
      'Timestamp': getCurrentTimestamp()
    }
  });
}

//根据项目名和子系统名查询子模块
export function  GetChildSysByName(projectName, childName, token) {
  return request({
    url:api + '/project/module/get/name',
    method: 'get',
    params: { projectName, childName },
    headers: {
      'Authorization':'Bearer '+ token,
      'content-type': 'application/json;charset=utf-8',
      'Timestamp': getCurrentTimestamp()
    }
  });
}

//新增子系统
export function AddChildSystem(data, token) {
  return request({
    url:api + '/project/child/add',
    method: 'post',
    data,
    headers: {
      'Authorization':'Bearer '+ token,
      'content-type': 'application/json;charset=utf-8',
      'Timestamp': getCurrentTimestamp()
    }
  });
}

//删除子系统
export function DeleteChildSystem(id, token) {
  return request({
    url:api + '/project/child/delete',
    method: 'delete',
    params:{ id },
    headers: {
      'Authorization':'Bearer '+ token,
      'content-type': 'application/json;charset=utf-8',
      'Timestamp': getCurrentTimestamp()
    }
  });
}

//编辑子系统
export function EditChildSystem(id, data, token) {
  return request({
    url:api + "/project/child/edit",
    method: 'put',
    data,
    params: id,
    headers: {
      'Authorization': 'Bearer ' + token,
      'content-type': 'application/json;charset=utf-8',
      'Timestamp': getCurrentTimestamp()
    }
  });
}

//根据子系统id获取子模块
export function GetChildModById(sysId, token) {
  return request({
    url:api +  "/module/get/min?sysId=" + sysId  ,
    method: 'get',
    params: { sysId },
    headers: {
      'Authorization':'Bearer '+ token,
      'content-type': 'application/json;charset=utf-8',
      'Timestamp': getCurrentTimestamp()
    }
  });
}

//新增子模块
export function AddChildModule(data, token) {
  return request({
    url:api + '/project/module/add',
    method: 'post',
    data,
    headers: {
      'Authorization':'Bearer '+ token,
      'content-type': 'application/json;charset=utf-8',
      'Timestamp': getCurrentTimestamp()
    }
  });
}

//删除子模块
export function DeleteChildModule(id, token) {
  return request({
    url:api + '/project/module/delete',
    method: 'delete',
    params:{ id },
    headers: {
      'Authorization':'Bearer '+ token,
      'content-type': 'application/json;charset=utf-8',
      'Timestamp': getCurrentTimestamp()
    }
  });
}

//编辑子模块
export function EditChildModule(id, data, token) {
  return request({
    url:api + "/project/module/edit",
    method: 'put',
    data,
    params:{ id },
    headers: {
      'Authorization': 'Bearer ' + token,
      'content-type': 'application/json;charset=utf-8',
      'Timestamp': getCurrentTimestamp()
    }
  });
}


//子模块详情
export function ModuleDetails(id, token) {
  return request({
    url:api + "/project/module/id",
    method: 'get',
    params:{ id },
    headers: {
      'Authorization': 'Bearer ' + token,
      'content-type': 'application/json;charset=utf-8',
      'Timestamp': getCurrentTimestamp()
    }
  });
}

//指定项目负责人
export function GetAppointOptions( token) {
  return request({
    url:api + "/project/pri",
    method: 'get',
    headers: {
      'Authorization': 'Bearer ' + token,
      'content-type': 'application/json;charset=utf-8',
      'Timestamp': getCurrentTimestamp()
    }
  });
}
